@@ -17,8 +17,10 @@ class MainHandler(tornado.web.RequestHandler):
             with open('./wsdl.xml') as f:
                 self.write(f.read())
                 self.set_header( 'Content-Type', 'text/xml' )
-                return
-        self.write(json.dumps(MainHandler.config, indent=4))
+                self.finish()
+        else:
+            self.write(json.dumps(MainHandler.config, indent=4))
+            self.finish()
 
     def post(self):
         url = self.request.path[1:]
